==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfListWidgetItem.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListWidgetItem(SpireObject):
    """
    Represents loaded list item.
    """

    @dispatch
    def __init__(self, text: str, value: str):
        """
        Initializes a new instance of the PdfListWidgetItem class.

        Args:
            text (str): The text of the item.
            value (str): The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV.argtypes = [c_wchar_p, c_wchar_p]
        GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV(text, value)
        super(PdfListWidgetItem, self).__init__(intPtr)

    @property
    def Text(self) -> str:
        """
        Gets or sets the text.

        Returns:
            str: The display text of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfListWidgetItem_get_Text.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfListWidgetItem_get_Text(self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets the text of the item.

        Args:
            value (str): The display text of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_set_Text.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfListWidgetItem_set_Text(self.Ptr, value)

    @property
    def Value(self) -> str:
        """
        Gets or sets the value.

        Returns:
            str: The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().PdfListWidgetItem_get_Value.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfListWidgetItem_get_Value(self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the item.

        Args:
            value (str): The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_set_Value.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfListWidgetItem_set_Value(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfListWidgetItem.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListWidgetItem(SpireObject):
    """
    Represents loaded list item.
    """

    @dispatch
    def __init__(self, text: str, value: str):
        """
        Initializes a new instance of the PdfListWidgetItem class.

        Args:
            text (str): The text of the item.
            value (str): The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV.argtypes = [c_wchar_p, c_wchar_p]
        GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListWidgetItem_CreatePdfListWidgetItemTV,text, value)
        super(PdfListWidgetItem, self).__init__(intPtr)

    @property
    def Text(self) -> str:
        """
        Gets or sets the text.

        Returns:
            str: The display text of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfListWidgetItem_get_Text.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfListWidgetItem_get_Text,self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets the text of the item.

        Args:
            value (str): The display text of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_set_Text.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfListWidgetItem_set_Text,self.Ptr, value)

    @property
    def Value(self) -> str:
        """
        Gets or sets the value.

        Returns:
            str: The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().PdfListWidgetItem_get_Value.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfListWidgetItem_get_Value,self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the item.

        Args:
            value (str): The value of the item.
        """
        GetDllLibPdf().PdfListWidgetItem_set_Value.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfListWidgetItem_set_Value,self.Ptr, value)
